@@ -29,7 +29,7 @@ class TestOpen(unittest.TestCase):
     def test_utf8(self):
         self.assertEquals(len(SubRipFile.open(self.utf8_path)), 1332)
         self.assertRaises(UnicodeDecodeError, SubRipFile.open,
-            self.windows_path)
+            self.windows_path, encoding='utf_8')
 
     def test_windows1252(self):
         srt_file = SubRipFile.open(self.windows_path, encoding='windows-1252')
@@ -228,6 +228,11 @@ class TestIntegration(unittest.TestCase):
         file = SubRipFile.open('/dev/null', error_handling=SubRipFile.ERROR_RAISE)
         self.assertEquals(len(file), 0)
 
+    def test_file_with_empty_items(self):
+        path = os.path.join(self.base_path, 'empty.srt')
+        file = SubRipFile.open(path)
+        self.assertEquals(len(file), 7)
+
     def test_blank_lines(self):
         items = list(SubRipFile.stream([u'\n'] * 20, error_handling=SubRipFile.ERROR_RAISE))
         self.assertEquals(len(items), 0)
